# Supernova classification Pipeline Leveraging Attributes of Supernova Hosts (SPLASH)

SPLASH classifies supernovae by using photometry to infer their host properties, and then using those properties (along with host-supernova angular separation) to predict supernova classes.

[Here](http://astrotimelab.com/_pages/splash.html) we are classifying supernova detections from LSST in real time!

Here's the scientific paper ***INSERT PAPER***!

## Installation
The pacakge can be installed from the python package index with
```
pip install astro_SPLASH
```
